@@ -479,7 +479,7 @@ def test_array_unallowed():
             (field, 'allowed'),
             errors.UNALLOWED_VALUES,
             ['agent', 'client', 'vendor'],
-            ['profit'],
+            (('profit',),),
         ),
     )
 
@@ -596,6 +596,11 @@ def test_regex(validator):
     )
 
 
+def test_regex_with_flag():
+    assert_success({"item": "hOly grAil"}, {"item": {"regex": "(?i)holy grail"}})
+    assert_fail({"item": "hOly grAil"}, {"item": {"regex": "holy grail"}})
+
+
 def test_a_list_of_dicts():
     assert_success(
         {
@@ -1114,8 +1119,8 @@ def test_options_passed_to_nested_validators(validator):
 
 
 def test_self_root_document():
-    """ Make sure self.root_document is always the root document.
-    See:
+    """
+    Make sure self.root_document is always the root document. See:
     * https://github.com/pyeve/cerberus/pull/42
     * https://github.com/pyeve/eve/issues/295
     """
@@ -1251,8 +1256,10 @@ def test_unicode_allowed():
 
 @mark.skipif(sys.version_info[0] < 3, reason='requires python 3.x')
 def test_unicode_allowed_py3():
-    """ All strings are unicode in Python 3.x. Input doc and schema
-    have equal strings and validation yield success."""
+    """
+    All strings are unicode in Python 3.x. Input doc and schema have equal strings and
+    validation yield success.
+    """
 
     # issue 280
     doc = {'letters': u'♄εℓł☺'}
@@ -1262,9 +1269,11 @@ def test_unicode_allowed_py3():
 
 @mark.skipif(sys.version_info[0] > 2, reason='requires python 2.x')
 def test_unicode_allowed_py2():
-    """ Python 2.x encodes value of allowed using default encoding if
-    the string includes characters outside ASCII range. Produced string
-    does not match input which is an unicode string."""
+    """
+    Python 2.x encodes value of allowed using default encoding if the string includes
+    characters outside ASCII range. Produced string does not match input which is an
+    unicode string.
+    """
 
     # issue 280
     doc = {'letters': u'♄εℓł☺'}
@@ -1946,3 +1955,21 @@ def test_require_all_and_exclude():
     assert_success({'foo': 'value'}, schema, validator)
     assert_success({'bar': 'value'}, schema, validator)
     assert_fail({'foo': 'value', 'bar': 'value'}, schema, validator)
+
+
+def test_allowed_when_passing_list_of_dicts():
+    # https://github.com/pyeve/cerberus/issues/524
+    doc = {'letters': [{'some': 'dict'}]}
+    schema = {'letters': {'type': 'list', 'allowed': ['a', 'b', 'c']}}
+
+    assert_fail(
+        doc,
+        schema,
+        error=(
+            'letters',
+            ('letters', 'allowed'),
+            errors.UNALLOWED_VALUES,
+            ['a', 'b', 'c'],
+            (({'some': 'dict'},),),
+        ),
+    )
